#!/bin/bash

#---------------------------------------
# Changer fond d'écran pour gdm3 écran de connexion
#
# d'après un script proposé par Nosselrahc
# dans forum ubuntu
# https://forum.ubuntu-fr.org/viewtopic.php?id=2006466
#
# version du 20190807
#
# on doit avoir dans le répertoire courant :
# * le fichier image nommé fond_ecran_gdm3.jpg ou fond_ecran_gdm3.png
# * le fichier gnome-shell-theme.gresource
#   ce fichier est à récupérer dans /usr/share/gnome-shell/
#   ne pas oublier d'en faire une sauvegarde avant de lancer ce script…
#
# NB : prérequis avec 2 paquets à installer
# → paquet nécessaire pour la commande glib-compile-resources :
#   libglib2.0-dev-bin
# → paquet nécessaire pour la commande convert :
#   imagemagick
#
#---------------------------------------

#----- -----
# variables
gdm="$(cat /etc/X11/default-display-manager | cut -d / -f4)"
fichier_gresource="gnome-shell-theme.gresource"
fichier_gresource_usr=/usr/share/gnome-shell/${fichier_gresource}
rep_tmp=gdmTheme
fichier_source_xml=${rep_tmp}/gnome-shell-theme.gresource.xml
fichier_css=${rep_tmp}/gnome-shell.css
fichier_css_save=${rep_tmp}/gnome-shell-sav.css

mode_texte()
{
    echo "Utilisation : $0 [-paramétre]"
    echo "paramètres possibles :"
    echo "   -h : afficher cet aide-mémoire"
    echo "   -jpg : image fond_ecran_gdm3.jpg (à mettre dans le répertoire courant)"
    echo "   -png : image fond_ecran_gdm3.png (à mettre dans le répertoire courant)"
}

mode_script()
{
    # on teste s'il y a ou non un paramètre
    if [ ! "$#" = "0" ]
    then
        case $1 in
            -jpg)
                # image au format jpg
                mode_image="jpg"
                fichier_image="fond_ecran_gdm3.jpg"
                fond_ecran="background.jpg"
            ;;
            -png)
                # image au format png
                mode_image="png"
                fichier_image="fond_ecran_gdm3.png"
                fond_ecran="background.png"
            ;;
            -h)
                # on affiche l'aide
                mode_texte
                exit 0
            ;;
            *)
                echo "paramètre $1 incorrect"
                # on affiche l'aide
                mode_texte
                exit 3
            ;;
        esac
    else
        echo "la commande doit avoir un paramètre"
        mode_texte
        exit 4
    fi
}

tester_paquet()
{
    # on teste le paquet $1
    paquet="$1"
    if ! dpkg --get-selections | grep ^${paquet} | grep install | cut -f1 | grep -q ^${paquet}$
    then
        echo "le paquet ${paquet} n'est pas installé"
        test_paquet="0"
    fi
}

verifier_prerequis()
{
    # on teste si on est bien en root
    #
    #if [ ! "$UID" = "0" ]
    #then
    #    echo "Vous devez être en root pour utiliser ce script !"
    #    exit 1
    #fi
    #
    # on teste si le gestionnaire de connexion est gdm3
    case ${gdm} in
        gdm3)
            true
        ;;
        *)
            echo "le gestionnaire de connexion n'est pas gdm3"
            exit 7
        ;;
    esac
    #
    # on teste si les paquets libglib2.0-dev-bin et imagemagick sont installés
    #
    test_paquet="1"
    tester_paquet "libglib2.0-dev-bin"
    tester_paquet "imagemagick"
    if [ "${test_paquet}" = "0" ]
    then
        echo "il manque des paquets : installez-les puis relancez le script"
        exit 5
    fi
    #
    # on teste la présence du fichier_image dans le répertoire courant
    #
    if [ ! -e "${fichier_image}" ]
    then
        echo "il n'y a pas le fichier ${fichier_image} dans le répertoire courant"
        exit 2
    fi
}

sauvegarder_theme_initial()
{
    # on sauvegarde le fichier initial
    #
    echo -ne "[===>                          ](10%)\r"
    sleep 1
    if [ ! -f "${fichier_gresource}.initial" ]
    then
        #cp ${fichier_gresource_usr} ${fichier_gresource}
        cp ${fichier_gresource} ${fichier_gresource}.initial
    else
        echo "il y a déjà un fichier ${fichier_gresource}.initial"
        exit 6
    fi
}


resolution_ecran()
{
    # géométrie de l'écran : largeur et hauteur
    #
    width=$(xrandr -q | grep -w "Screen 0" | awk -F'current' '{print $2 }' | awk -F',' '{print $1 }' | awk -F' ' '{print $1 }')
    height=$(xrandr -q | grep -w "Screen 0" | awk -F'current' '{print $2 }' | awk -F',' '{print $1 }'|  awk -F' ' '{print $3 }')
}

creer_repertoire_temporaire()
{
    # création du répertoire temporaire
    #
    if [ ! -d "${rep_tmp}" ]
    then
        mkdir -p ${rep_tmp}/icons
    fi
}

creer_fichier_xml()
{
    # création du fichier gresource au format xml
    # dans le répertoire temporaire
    #
    echo -ne "[======>                       ](20%)\r"
    # l'entête du fichier xml'
    echo '<?xml version="1.0" encoding="UTF-8"?>' > ${fichier_source_xml}
    echo "<gresources>" >> ${fichier_source_xml}
    echo '  <gresource prefix="/org/gnome/shell/theme">' >> ${fichier_source_xml}
}

extraire_theme()
{
    # extraction du thème initial dans le fichier xml
    # écriture d'une ligne supplémentaire pour le fichier image background.jpg ou background.png
    #
    pattern_noise="noise-texture.png"
    pattern_image=${fond_ecran}
    for r in `gresource list ${fichier_gresource}`
    do
        if ! grep -q "$pattern_noise" <<< "$r"
        then
            if ! grep -q "$pattern_image" <<< "$r"
            then
                echo "    <file>${r#\/org\/gnome\/shell\/theme/}</file>" >> ${fichier_source_xml}
            fi
        else
            echo "    <file>${r#\/org\/gnome\/shell\/theme/}</file>" >> ${fichier_source_xml}
            echo "    <file>${fond_ecran}</file>" >> ${fichier_source_xml}
        fi
        gresource extract ${fichier_gresource} $r >${rep_tmp}/${r#\/org\/gnome\/shell\/theme/}
    done
    # écrire les balises de fin du fichier xml
    #
    echo "  </gresource>" >> ${fichier_source_xml}
    echo "</gresources>" >> ${fichier_source_xml}
}

modifier_fichier_css()
{
    # on modifie le fichier css pour la partie lockDialogGroup
    #
    echo -ne "[==========>                   ](40%)\r"
    sleep 1
    cp ${fichier_css} ${fichier_css_save}
    flag="-1"
    pattern_lock="#lockDialogGroup"
    pattern_fin="}"
    while IFS=$"\n" read line
    do  
        if [ "${flag}" = "-1" ]
        then
            flag="0"
            echo "${line}" > ${fichier_css}
        else
            if grep -q "$pattern_lock" <<< "${line}"
            then
                flag="1"
                echo "${line}" >> ${fichier_css}
                echo "  background: #2e3436 url(${fond_ecran});" >> ${fichier_css}
                echo "  background-size: ${width}px ${height}px;" >> ${fichier_css}
                echo "  background-repeat: no-repeat; }" >> ${fichier_css}
            fi
            if [ ! "${flag}" = "1" ]
            then
                echo "${line}" >> ${fichier_css}
            fi
            if grep -q "$pattern_fin" <<< "${line}"
            then
                flag="0"
            fi
        fi
    done < ${fichier_css_save}
}

convertir_taille_image()
{
    # on convertit l'image à la taille de l'écran
    # et on la place dans le répertoire temporaire
    #
    echo -ne "[==============>               ](50%)\r"
    sleep 1
    convert "${fichier_image}" -resize ${width}x${height}\! ${rep_tmp}/${fond_ecran}
}

recompiler_theme()
{
    # on compile le nouveau thème
    #
    echo -ne "[=================>            ](60%)\r"
    sleep 1
    cd ${rep_tmp}
    glib-compile-resources gnome-shell-theme.gresource.xml
    cd ..
}

copier_nouveau_theme()
{
    # on récupère le nouveau thème
    # il faudra le mettre en place dans /usr/share/gnome-shell/
    #
    echo -ne "[=======================>      ](80%)\r"
    sleep 1
    cp ${rep_tmp}/${fichier_gresource} ${fichier_gresource}.nouveau
    echo -ne "[=============================>](100%)\r"
    sleep 1
    echo "le nouveau thème est disponible : ${fichier_gresource}.nouveau"
    echo "vous pouvez le placer à l'aide des commandes suivantes (en root) :"
    echo "mv ${fichier_gresource_usr} ${fichier_gresource_usr}.save"
    echo "cp ${PWD}/${fichier_gresource}.nouveau ${fichier_gresource_usr}"
}

supprimer_repertoire_temporaire()
{
    # suppression du répertoire temporaire
    #
    rm -rf ${rep_tmp}
}

#---------------
# programme
#
mode_script "$@"
verifier_prerequis
sauvegarder_theme_initial
resolution_ecran
creer_repertoire_temporaire
creer_fichier_xml
extraire_theme
modifier_fichier_css
convertir_taille_image
recompiler_theme
copier_nouveau_theme
supprimer_repertoire_temporaire
exit 0
#
# fin programme
#---------------
