#!/bin/bash

#####    ##### ##### #####
#
# Script à utiliser pour installer une imprimante en fonction du parc
# le parc est déterminer par le préfixe du nom du client-linux
#
#
# version du 20130606 → non testé pour se4 ! [TODO]
#
#
#
#####    ##### ##### #####

#####
# quelques variables
ladate=$(date +%Y%m%d%H%M%S)
compte_rendu=/root/compte_rendu_imprimante_${ladate}.txt

#####
# le serveur SE3
#
SE3_IP="192.168.1.3"
url_recuperer="http://${SE3_IP}/install/messcripts_perso"

#####
# Les dépôts à utiliser
#
DEPOT_epson="download.ebz.epson.net"

#####
# paramètres pour les imprimantes
# Il suffit de commenter le nom (ou de ne rien mettre) pour ne pas l'installer
#
# parc techno
nom_imprimante_techno="hp4100n"
ip_imprimante_techno="192.168.1.21"
ppd_imprimante_techno="hp-laserjet_4100_series-ps.ppd"
#
# parc tec1
nom_imprimante_tec1="hp4100n"
ip_imprimante_tec1="192.168.1.21"
ppd_imprimante_tec1="hp-laserjet_4100_series-ps.ppd"
#
# parc tec2
nom_imprimante_tec2="hp4100n"
ip_imprimante_tec2="192.168.1.21"
ppd_imprimante_tec2="hp-laserjet_4100_series-ps.ppd"
#
# parc smm1
nom_imprimante_smm1="EpsonM2400"
ip_imprimante_smm1="192.168.1.23"
ppd_imprimante_smm1="Epson-AL-M2400-Postscript-Epson.ppd"
#
# parc smm2
nom_imprimante_smm2="Dell5330dn"
ip_imprimante_smm2="192.168.1.24"
ppd_imprimante_smm2="Dell-M5200-Postscript.ppd"
#
# parc cdi
nom_imprimante_cdi="Dell5210n"
ip_imprimante_cdi="192.168.1.22"
ppd_imprimante_cdi="Dell_Laser_Printer_5210n_fr.PPD"
#
# parc prof
# en fait, il s'agit de la photocopieuse
nom_imprimante_prof="konica554e"
ip_imprimante_prof="192.168.1.27"
ppd_imprimante_prof="konica554e.ppd"
#
# la photocopieuse en salle des profs
# pour mémoire
nom_imprimante_photocopieuse="konica554e"
ip_imprimante_photocopieuse="192.168.1.27"
ppd_imprimante_photocopieuse="konica554e.ppd"
#
# parcs test, cours et tni
# → pas d'imprimante
# (sauf tni-sp1 qui est en tec1)

#####
# nom de la machine et nom du parc
#
# nom de la machine
NOMHOTE=$(hostname)
# nom du parc
PARC=$(echo "$NOMHOTE" | cut -d"-" -f1)

installer_paquet()
{
    # installation d'un paquet
    # 1 paramètre
    # $1 → le nom du paquet à installer
    #
    paquet="$1"
    # on vérifie si le paquet est déjà installé
    if ! dpkg --get-selections | grep ^${paquet} | grep install | cut -f1 | grep -q ^${paquet}$
    then
        echo -e "${vert}on installe $paquet" | tee -a $compte_rendu
        echo -e "==========${neutre}" | tee -a $compte_rendu
        DEBIAN_FRONTEND=noninteractive apt-get -q2 install "$paquet" #>/dev/null #2>&1
        # on vérifie si l'installation s'est bien déroulée
        if [ "$?" != "0" ]
        then
            echo -e "${rouge}"
            echo -e "un problème a eu lieu lors de l'installation de $paquet" | tee -a $compte_rendu
            echo -e "==========${neutre}" | tee -a $compte_rendu
        fi
    else
        echo -e "${orange}$paquet est déjà installé…" | tee -a $compte_rendu
        echo -e "==========${neutre}" | tee -a $compte_rendu
        return 1
    fi
}

gestion_imprimante()
{
    # installation de l'imprimante, en fonction du parc
    # prendre cette imprimante comme imprimante par défaut
    #
    echo -e ""
    echo -e "Installation des imprimantes" | tee -a $compte_rendu
    echo -e ""
    #
    # choix de l'imprimante en fonction du parc
    eval nom_imprimante='$'nom_imprimante_$PARC
    eval ip_imprimante='$'ip_imprimante_$PARC
    eval ppd_imprimante='$'ppd_imprimante_$PARC
    #inter=$"nom_imprimante_$PARC"    # solution alternative avec une variable intermédiaire
    #nom_imprimante=${!inter}
    #inter=$"ip_imprimante_$PARC"
    #ip_imprimante=${!inter}
    #inter=$"ppd_imprimante_$PARC"
    #ppd_imprimante=${!inter}
    #
    case "$PARC" in
        tec1|tec2|techno|smm1|smm2|cdi|prof)
            [[ "$nom_imprimante" = "" ]] && break
            wget -q $url_recuperer/imprimantes/$ppd_imprimante
            if [ "$?" = "0" ]
            then
                echo -e "installation de l'imprimante ${bleu}$nom_imprimante${neutre} pour le parc ${bleu}$PARC${neutre}" | tee -a $compte_rendu
                echo -e "imprimante par défaut"
                echo -e "${bleu}==========${neutre}"
                lpadmin -p $nom_imprimante -v socket://$ip_imprimante:9100 -E -P /root/bin/$ppd_imprimante && lpadmin -d $nom_imprimante
            else
                echo -e "${rouge}On n'a pas récupéré le fichier $ppd_imprimante${neutre}" | tee -a $compte_rendu
                echo -e "${bleu}==========${neutre}"
                sleep 3s
            fi
        ;;
        tni)
            case $NOMHOTE in
                tni-sp1)
                    # cas particulier : tni-sp1 est en techno
                    nom_imprimante="$nom_imprimante_techno"
                    ip_imprimante="$ip_imprimante_techno"
                    ppd_imprimante="$ppd_imprimante_techno"
                    [[ "$nom_imprimante" = "" ]] && break
                    wget -q $url_recuperer/imprimantes/$ppd_imprimante
                    if [ "$?" = "0" ]
                    then
                        echo -e "installation de l'imprimante $nom_imprimante pour la machine $NOMHOTE" | tee -a $compte_rendu
                        echo -e "${bleu}==========${neutre}"
                        lpadmin -p $nom_imprimante -v socket://$ip_imprimante:9100 -E -P /root/bin/$ppd_imprimante && lpadmin -d $nom_imprimante
                    else
                        echo -e "On n'a pas récupéré le fichier $ppd_imprimante" | tee -a $compte_rendu
                        echo -e "${rouge}==========${neutre}"
                        sleep 3s
                    fi
                ;;
                *)
                    echo -e "pas d'imprimante installée" | tee -a $compte_rendu
                    echo -e "${bleu}==========${neutre}"
                ;;
            esac
        ;;
        *)
            case $NOMHOTE in
                cours-eg81|cours-eg82)
                    # on installe l'imprimante usb Epson
                    # via les dépôts Epson
                    echo -e "Mise en place du dépôt $DEPOT_epson" | tee -a $compte_rendu
                    echo -e "${bleu}==========${neutre}"
                    echo "deb http://$DEPOT_epson/dsc/op/stable/debian/ lsb3.2 main" >> /etc/apt/sources.list.d/epson.list
                    # ajout des clefs du dépôts
                    echo -e "Installation des clefs du dépôt $DEPOT_epson" | tee -a $compte_rendu
                    echo -e "${bleu}==========${neutre}"
                    apt-key adv --recv-keys --keyserver keyserver.ubuntu.com 8AA65D56 | tee -a $compte_rendu
                    echo -e "On recharge la liste des paquets"
                    echo -e "${bleu}==========${neutre}" | tee -a $compte_rendu
                    ap-get -q2 update
                    if [ "$?" != "0" ]
                    then
                        echo -e "${rouge}le rechargement de la liste des paquets ne s'est pas fait correctement${neutre}"
                        echo -e "${bleu}==========${neutre}"
                    fi
                    # on installe l'imprimante Epson WF-7015
                    echo "On installe l'imprimante Epson WF-7015" | tee -a $compte_rendu
                    installer_paquet epson-inkjet-printer-201115w
                ;;
                *)
                    echo -e "pas d'imprimante installée" | tee -a $compte_rendu
                    echo -e "${bleu}==========${neutre}"
                ;;
            esac
        ;;
    esac
    echo -e ""
}

gestion_imprimante
exit 0
