#!/bin/bash

#Mise en place d'apt-cacher-ng pour la mise en cache des paquets



# variables à déclarer
DATE=`date +%Y-%m-%d-%H-%M`
LOG="/root/CR-install-apt-cacher-ng.log"
PORT_APT_CACHER_NG="9999"
SECURITY_CONF="/etc/apt-cacher-ng/security.conf"
APT_CACHER_NG_CONF="/etc/apt-cacher-ng/acng.conf"
CACHE_DIR="/var/sambaedu/apt-cacher-ng/"

# variables sambaedu à récupérer des fichiers de configuration
. /usr/share/sambaedu/includes/config.inc.sh

# Lecture des parametres sambaedu.conf*
get_config

# On rend l'install silencieuse
apt install -y debconf-utils
echo "apt-cacher-ng     apt-cacher-ng/tunnelenable      boolean false" | debconf-set-selections

#mdp adminse3 stocké dans /etc/sambaedu/sambaedu.conf.d/clients.conf
adminse_passwd=$config_adminse_passwd

#proxy à récupérer? au cas où c'est ici
#proxy_config=$config_http_proxy

touch "$LOG"
chmod 600 "$LOG"

echo "Installation d'apt-cacher-ng du $DATE" >>"$LOG"
#Création du répertoire contenant le cache et installation du paquet
mkdir -p $CACHE_DIR
apt-get update >>"$LOG" 2>&1
apt-get install apt-cacher-ng 
chown -R apt-cacher-ng:apt-cacher-ng  $CACHE_DIR

#Ajout des identifiants/mdp au fichier security.conf
echo "AdminAuth: admin:$adminse_passwd" >"$SECURITY_CONF"
chown apt-cacher-ng:apt-cacher-ng "$SECURITY_CONF"
chmod 600 "$SECURITY_CONF"

#On remplace le fichier de conf existant par celui contenant uniquement les infos utiles
cat <<EOF> "$APT_CACHER_NG_CONF"
CacheDir:  $CACHE_DIR
LogDir: /var/log/apt-cacher-ng
Port:$PORT_APT_CACHER_NG
Remap-debrep: file:deb_mirror*.gz /debian ;file:backends_debian
Remap-uburep: file:ubuntu_mirrors /ubuntu ; file:backends_ubuntu
Remap-debvol: file:debvol_mirror*.gz /debian-volatile ;file:backends_debvol
Remap-cygwin: file:cygwin_mirrors /cygwin # ; file:backends_cygwin # incomplete, please create this file
ReportPage: acng-report.html
VerboseLog: 1
ExTreshold: 4
PassThroughPattern: ^(.*):443$

#pattern modifiés pour la gestion de la clef sambaedu.gpg.key dans le preseed.
VfilePattern = (^|.*/)(Index|Packages(\.gz|\.yml.gz|\.bz2|\.lzma|\.xz)?|InRelease|Release|Release\.gpg|custom\.gpg|sambaedu\.gpg\.key|mirrors.txt|Sources(\.gz|\.bz2|\.lzma|\.xz)?|release|index\.db-.*\.gz|Contents-[^/]*(\.gz|\.bz2|\.lzma|\.xz)?|pkglist[^/]*\.bz2|rclist[^/]*\.bz2|meta-release[^/]*|Translation[^/]*(\.gz|\.bz2|\.lzma|\.xz)?|MD5SUMS|SHA1SUMS|SHA256SUMS|((setup|setup-legacy)(\.ini|\.bz2|\.hint)(\.sig)?)|mirrors\.lst|repo(index|md)\.xml(\.asc|\.key)?|directory\.yast|products|content(\.asc|\.key)?|media|filelists\.xml\.gz|filelists\.sqlite\.bz2|repomd\.xml|packages\.[a-zA-Z][a-zA-Z]\.gz|info\.txt|license\.tar\.gz|license\.zip|.*\.(db|files|abs)(\.tar(\.gz|\.bz2|\.lzma|\.xz))?|metalink\?repo|.*prestodelta\.xml\.gz|repodata/.*\.(xml|sqlite)(\.gz|\.bz2|\.lzma|\.xz))$|/dists/.*/installer-[^/]+/[^0-9][^/]+/images/.*
PfilePattern = .*(\.d?deb|\.rpm|\.drpm|\.yml.gz|\.key|\.dsc|\.tar(\.gz|\.bz2|\.lzma|\.xz)(\.gpg)?|\.diff(\.gz|\.bz2|\.lzma|\.xz)|\.jigdo|\.template|changelog|copyright|\.udeb|\.debdelta|\.diff/.*\.gz|(Devel)?ReleaseAnnouncement(\?.*)?|[a-f0-9]+-(susedata|updateinfo|primary|deltainfo).xml.gz|fonts/(final/)?[a-z]+32.exe(\?download.*)?|/dists/.*/installer-[^/]+/[0-9][^/]+/images/.*)$

EOF

# configuration du proxy
# si le proxy est déclaré dans l'interface, on le reporte dans la conf du cache :
if [ "$config_proxy_type" = "manuel" ]; then
echo "Proxy: http://$config_proxy_address:$config_proxy_port" >> $APT_CACHER_NG_CONF
elif [ "$config_proxy_type" = "automatique" ]; then
echo "Proxy: http://$config_proxy_address:$config_proxy_port" >> $APT_CACHER_NG_CONF
else
echo "# Pas de proxy" >> $APT_CACHER_NG_CONF
fi

#On écrit directement les paramètres d'apt-cacher-ng dans le fichier /etc/sambaedu/sambaedu.conf.d/clients.conf pour qu'ils soient pris en compte dans les preseed.
set_config clients apt_proxy "http://$config_se4fs_ip:$PORT_APT_CACHER_NG"

#On relance le service pour que les modifs soient prises en compte
systemctl restart apt-cacher-ng 
service apt-cacher-ng status >>"$LOG" 2>&1
exit
