#!/bin/bash
# script de mise en place/mise à jour des installateurs ubuntu/ubuntu
# à partir des netboot.tar.gz
# incorporation des firmwares non libres pour ubuntu
#
# version du 20190806
#
# 2 modes de fonctionnement : verbeux ou silencieux
#
# [TODO] : ubuntu ? bionic ?
# [TODO] : i386 ?
# [TODO] : mettre en paramètres ubuntu/ubuntu et version ?
#
#####

#####
# les variables
. /usr/share/sambaedu/includes/config.inc.sh
get_config

mode=""
ladate=$(date +%Y%m%d%H%M%S)
compte_rendu=/root/compte_rendu_install_netboot_${ladate}.txt
#
url_ubuntu="fr.archive.ubuntu.com/ubuntu"
if  [ -z "$config_version_ubuntu" ] ;
then
	version_ubuntu="focal"
else
	version_ubuntu=$config_version_ubuntu
fi

depot_firmware_ubuntu="cdimage.ubuntu.org/cdimage/unofficial/non-free/firmware"
#
url_ubuntu="fr.archive.ubuntu.com/ubuntu"
if  [ -z "$config_version_ubuntu" ] ;
then
	version_ubuntu="focal"
else
	version_ubuntu=$config_version_ubuntu
fi
#
rep_install="/var/sambaedu/unattended/install"

#####
# les fonctions

mode_script()
{
    # gestion du paramètre éventuel $1
    if [ ! "$#" = "0" ]
    then
        case $1 in
            -h)
                # on affiche l'aide
                mode_texte
                exit 0
            ;;
            -v)
                # mode verbeux pour une utilisation manuelle
                mode="verbeux"
            ;;
            -s)
                # mode silencieux pour une utilisation via la crontab
                mode="silence"
            ;;
            *)
                echo "paramètre $1 incorrect"
                # on affiche l'aide
                mode_texte
                exit 2
            ;;
        esac
    else
        # pas de paramètre
        # mode verbeux par défaut
        mode="verbeux"
    fi
}

mode_texte()
{
    echo "Utilisation : $0 [-paramétre]"
    echo "paramètres possibles :"
    echo "   -h : afficher cet aide-mémoire"
    echo "   -s : script silencieux, utilisation avec crontab"
    echo "   -v : script verbeux, utilisation en manuel"
}

tester_repertoires()
{
    # existence de l'arborescence /var/sambaedu/unattended/install/os/iso/
    if [ -e "${rep_install}/os/iso/" ]
    then
        return 0
    else
        mkdir -p ${rep_install}/os/iso/
        return 0
    fi
}

tester_checksums_firmware()
{
    # téléchargement sha256sums dépôt
    wget -q http://$depot_firmware_ubuntu/$version_ubuntu/current/SHA256SUMS
    eval sha256sums_firmware_depot_${version_ubuntu}=$(cat SHA256SUMS | grep "firmware.cpio.gz" | cut -f1 -d" ")
    rm -f SHA256SUMS
    # calculer sha256sums local
    if [ -e "${rep_install}/os/iso/firmware_${version_ubuntu}.cpio.gz" ]
    then
        eval sha256sums_firmware_local_${version_ubuntu}=$(sha256sum ${rep_install}/os/iso/firmware_${version_ubuntu}.cpio.gz | cut -f1 -d" ")
    else
        eval sha256sums_firmware_local_${version_ubuntu}=""
    fi
    # comparer les sha256sums
    eval a='$'sha256sums_firmware_local_${version_ubuntu}
    eval b='$'sha256sums_firmware_depot_${version_ubuntu}
    if [ "$a" = "$b" ]
    then
        # inutile de télécharger firmware.cpio.gz
        echo "test négatif firmware_${version_ubuntu}.cpio.gz" >> ${compte_rendu}
        return 0
    else
        # il faut télécharger firmware.cpio.gz
        echo "test positif firmware_${version_ubuntu}.cpio.gz" >> ${compte_rendu}
        [ -e "${rep_install}/os/iso/firmware_${version_ubuntu}.cpio.gz" ] && find ${rep_install}/os/iso/firmware_${version_ubuntu}.cpio.gz -delete
        return 1
    fi
}

telecharger_firmware()
{
    # télécharger les firmwares non libres
    if [ "${mode}" = "silence" ]
    then
        wget -P ${rep_install}/os/iso/ -O ${rep_install}/os/iso/firmware_${version_ubuntu}.cpio.gz -q http://${depot_firmware_ubuntu}/${version_ubuntu}/current/firmware.cpio.gz
    else
        wget -P ${rep_install}/os/iso/ -O ${rep_install}/os/iso/firmware_${version_ubuntu}.cpio.gz -q --show-progress http://${depot_firmware_ubuntu}/${version_ubuntu}/current/firmware.cpio.gz
    fi
    echo "firmware_${version_ubuntu}.cpio.gz téléchargé" >> ${compte_rendu}
}

tester_checksums_netboot()
{
    # 2 arguments :
    # $1 → ubuntu ou ubuntu
    # $2 → i386 ou amd64
    #
    eval url_dists='$'url_${1}
    eval version='$'version_${1}
    # téléchargement sha256sums dépôt
    wget -q http://$url_dists/dists/$version/main/installer-${2}/current/legacy-images/SHA256SUMS
    eval sha256sums_netboot_depot_${version}_${2}=$(cat SHA256SUMS | grep "./netboot/netboot.tar.gz" | cut -f1 -d" ")
    rm -f SHA256SUMS
    # calculer sha256sums local
    if [ -e "${rep_install}/os/iso/netboot_${version}_${2}.tar.gz" ]
    then
        eval sha256sums_netboot_local_${version}_${2}=$(sha256sum ${rep_install}/os/iso/netboot_${version}_${2}.tar.gz | cut -f1 -d" ")
    else
        eval sha256sums_netboot_local_${version}_${2}=""
    fi
    # comparer les sha256sums
    eval a='$'sha256sums_netboot_local_${version}_${2}
    eval b='$'sha256sums_netboot_depot_${version}_${2}
    if [ "$a" = "$b" ]
    then
        # inutile de télécharger netboot/netboot.tar.gz
        echo "test négatif netboot_${version}_${2}.tar.gz" >> ${compte_rendu}
        return 0
    else
        # il faut télécharger netboot/netboot.tar.gz
        [ -e "${rep_install}/os/iso/netboot_${version}_${2}.tar.gz" ] && find ${rep_install}/os/iso/netboot_${version}_${2}.tar.gz -delete
        echo "test positif netboot_${version}_${2}.tar.gz" >> ${compte_rendu}
        return 1
    fi
}

telecharger_netboot()
{
    # 2 arguments :
    # $1 → ubuntu ou ubuntu
    # $2 → i386 ou amd64
    #
    # téléchargement des netboot ubuntu/ubuntu 32 bits/64 bits
    eval url_dists='$'url_${1}
    eval version='$'version_${1}
    if [ "${mode}" = "silence" ]
    then
        wget -P ${rep_install}/os/iso/ -O ${rep_install}/os/iso/netboot_${version}_${2}.tar.gz -q http://${url_dists}/dists/${version}/main/installer-${2}/current/legacy-images/netboot/netboot.tar.gz
    else
        wget -P ${rep_install}/os/iso/ -O ${rep_install}/os/iso/netboot_${version}_${2}.tar.gz -q --show-progress http://${url_dists}/dists/${version}/main/installer-${2}/current/legacy-images/netboot/netboot.tar.gz
    fi
    echo "netboot_${version}_${2}.tar.gz téléchargé" >> ${compte_rendu}
}

extraire_netboot()
{
    # 2 arguments :
    # $1 → ubuntu ou ubuntu
    # $2 → i386 ou amd64
    #
    # extraction des netboot
    eval version='$'version_${1}
    tar xfz ${rep_install}/os/iso/netboot_${version}_${2}.tar.gz -C ${rep_install}/os/ ./${1}-installer/${2}/
    chown -R  www-admin ${rep_install}/os/ubuntu-installer/
    echo "répertoire ${rep_install}/os/${1}-installer/${2}/ en place" >> ${compte_rendu}
}

incorporer_firmware()
{
    # 1 argument :
    # $1 → i386 ou amd64
    cp -p ${rep_install}/os/ubuntu-installer/${1}/initrd.gz ${rep_install}/os/ubuntu-installer/${1}/initrd.gz.orig
    cat ${rep_install}/os/ubuntu-installer/${1}/initrd.gz.orig ${rep_install}/os/iso/firmware_${version_ubuntu}.cpio.gz > ${rep_install}/os/ubuntu-installer/${1}/initrd.gz
    rm -f ${rep_install}/os/ubuntu-installer/${1}/initrd.gz.orig
    echo "firmware ubuntu incorporé pour ${1}" >> ${compte_rendu}
}

#####
# le programme

mode_script $1
echo -e "Compte-rendu de la mise en place ou de la mise à jour de l'installateur ubuntu : ${ladate}\n" > ${compte_rendu}
tester_repertoires
if [ "$?" = "1" ]
then
    echo "il n'y a pas l'arborescence ${rep_install}/os/iso/" | tee -a ${compte_rendu}
    exit 1
fi
#tester_sha256sums_firmware
#if [ "$?" = "1" ]
#then
#    telecharger_firmware
#fi
tester_checksums_netboot ubuntu amd64
if [ "$?" = "1" ]
then
    telecharger_netboot ubuntu amd64
fi
[ -e "${rep_install}/os/ubuntu-installer/amd64/" ] && find ${rep_install}/os/ubuntu-installer/amd64/ -delete
extraire_netboot ubuntu amd64
#incorporer_firmware amd64
exit 0
